IcpConfig

Struct IcpConfig 

pub struct IcpConfig {
    pub max_iterations: usize,
    pub max_correspondence_distance: f32,
    pub transformation_epsilon: f64,
    pub fitness_epsilon: f64,
    pub min_correspondences: usize,
    pub initial_guess: Isometry3<f32>,
}
Configuration for point-to-point ICP.

Fields

max_iterations: usize

Maximum number of ICP iterations.

max_correspondence_distance: f32

Maximum correspondence distance.

transformation_epsilon: f64

Stop when the transform update is smaller than this threshold.

fitness_epsilon: f64

Stop when fitness improvement is smaller than this threshold.

min_correspondences: usize

Minimum number of correspondences required per iteration.

initial_guess: Isometry3<f32>

Initial transform guess mapping source into target frame.

Implementations

Source

impl IcpConfig

pub fn with_correspondence_distance(max_correspondence_distance: f32) -> Self

Creates a config with the given correspondence distance.